@@ -1,9 +1,9 @@
 package BorderStyle::UTF8::SingleLineBoldHeader;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-01-24'; # DATE
+our $DATE = '2021-01-31'; # DATE
 our $DIST = 'BorderStyles-Standard'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use strict;
 use parent 'BorderStyleBase';
@@ -19,6 +19,9 @@ our %BORDER = (
         ['│','│','│'],     # 3
         ['├','─','┼','┤', '┬','┴','├','┤'], # 4
         ['└','─','┴','┘'], # 5
+
+        ['┌','─','┬','┐'], # 6
+        ['┗','━','┻','┛'], # 7
     ],
     utf8 => 1,
 );
@@ -38,7 +41,7 @@ BorderStyle::UTF8::SingleLineBoldHeader - Single-line border (header box bold) w
 
 =head1 VERSION
 
-This document describes version 0.004 of BorderStyle::UTF8::SingleLineBoldHeader (from Perl distribution BorderStyles-Standard), released on 2021-01-24.
+This document describes version 0.005 of BorderStyle::UTF8::SingleLineBoldHeader (from Perl distribution BorderStyles-Standard), released on 2021-01-31.
 
 =head1 SYNOPSIS
 
